| Title: | What the Package Does (One Line, Title Case) |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | Shinya Uryu [aut, cre] (ORCID: <https://orcid.org/0000-0002-0493-6186>) |
| Maintainer: | Shinya Uryu <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-17 06:35:46 UTC |
| Source: | https://github.com/uribo/easyestat |
Download Japan prefecture map from e-Stat
download_stat_map( prefcode, exdir = ".", dest = TRUE, .survey_id = c("A002005212015") )download_stat_map( prefcode, exdir = ".", dest = TRUE, .survey_id = c("A002005212015") )
prefcode |
The JIS-code for prefecture and city identical number. If prefecture, must be from 1 to 47. |
exdir |
The directory to extract files to (the equivalent of
|
dest |
If TRUE, to unzip downloaded files. |
.survey_id |
survey id (A00200521YYYY is small area, D00200521YYYY is did area) |
The GIS data downloaded from e-Stat is read and converted into an easy to process sf::sf format.
You can use download_stat_map() to download the data.
read_estat_map(file, type = "aggregate_unit", remove_cols = TRUE)read_estat_map(file, type = "aggregate_unit", remove_cols = TRUE)
file |
Path to downloaded e-Stat shape file |
type |
Currently, only "aggregate_unit" is used. |
remove_cols |
Whether or not to remove redundant columns. When TRUE (the default), the following columns are removed (See details). These columns can be substituted or sought with values from other columns.
|
Read e-Stat mesh population census data
read_estat_meshpop(file, is_long = FALSE, mesh_size = 0.5)read_estat_meshpop(file, is_long = FALSE, mesh_size = 0.5)
file |
Path to downloaded e-Stat text file,
such as |
is_long |
If TRUE, make the population category a single variable and make the values of the counterpart population independent. |
mesh_size |
Currently, only 0.5 (500m mesh) |